@@ -36,6 +36,7 @@ DBusMessage *__connman_error_failed(DBusMessage *msg, int errnum);
 DBusMessage *__connman_error_invalid_arguments(DBusMessage *msg);
 DBusMessage *__connman_error_permission_denied(DBusMessage *msg);
 DBusMessage *__connman_error_passphrase_required(DBusMessage *msg);
+DBusMessage *__connman_error_not_registered(DBusMessage *msg);
 DBusMessage *__connman_error_not_supported(DBusMessage *msg);
 DBusMessage *__connman_error_not_implemented(DBusMessage *msg);
 DBusMessage *__connman_error_not_found(DBusMessage *msg);
@@ -55,15 +56,23 @@ int __connman_selftest(void);
 
 #include <connman/types.h>
 
-int __connman_manager_init(DBusConnection *conn, gboolean compat);
+int __connman_manager_init(gboolean compat);
 void __connman_manager_cleanup(void);
 
-int __connman_agent_init(DBusConnection *conn);
+int __connman_agent_init(void);
 void __connman_agent_cleanup(void);
 
 int __connman_agent_register(const char *sender, const char *path);
 int __connman_agent_unregister(const char *sender, const char *path);
 
+struct connman_service;
+
+typedef void (* passphrase_cb_t) (struct connman_service *service,
+				const char *passphrase, void *user_data);
+
+int __connman_agent_request_passphrase(struct connman_service *service,
+				passphrase_cb_t callback, void *user_data);
+
 #include <connman/log.h>
 
 int __connman_log_init(gboolean detach, gboolean debug);
@@ -170,8 +179,7 @@ void __connman_driver_rescan(struct connman_driver *driver);
 
 #include <connman/element.h>
 
-int __connman_element_init(DBusConnection *conn, const char *device,
-							const char *nodevice);
+int __connman_element_init(const char *device, const char *nodevice);
 void __connman_element_start(void);
 void __connman_element_stop(void);
 void __connman_element_cleanup(void);
@@ -215,6 +223,8 @@ int __connman_element_append_ipv4(struct connman_element *element,
 int __connman_element_set_ipv4(struct connman_element *element,
 				const char *name, DBusMessageIter *value);
 
+gboolean __connman_element_device_isfiltered(const char *devname);
+
 int __connman_ipv4_init(void);
 void __connman_ipv4_cleanup(void);
 
@@ -229,6 +239,7 @@ void __connman_udev_cleanup(void);
 char *__connman_udev_get_devtype(const char *ifname);
 char *__connman_udev_get_mbm_devnode(const char *ifname);
 void __connman_udev_rfkill(const char *sysname, connman_bool_t blocked);
+void __connman_udev_enable_rfkill_processing(void);
 
 #include <connman/device.h>
 
@@ -261,6 +272,10 @@ int __connman_device_disconnect(struct connman_device *device);
 
 connman_bool_t __connman_device_has_driver(struct connman_device *device);
 
+void __connman_device_set_reconnect(struct connman_device *device,
+						connman_bool_t reconnect);
+connman_bool_t __connman_device_get_reconnect(struct connman_device *device);
+
 const char *__connman_device_get_type(struct connman_device *device);
 const char *__connman_device_get_ident(struct connman_device *device);
 
@@ -286,7 +301,7 @@ connman_bool_t __connman_network_get_weakness(struct connman_network *network);
 
 #include <connman/profile.h>
 
-int __connman_profile_init(DBusConnection *conn);
+int __connman_profile_init();
 void __connman_profile_cleanup(void);
 
 connman_bool_t __connman_profile_get_offlinemode(void);
@@ -328,6 +343,7 @@ struct connman_service *__connman_service_create_from_network(struct connman_net
 void __connman_service_update_from_network(struct connman_network *network);
 void __connman_service_remove_from_network(struct connman_network *network);
 
+const char *__connman_service_get_path(struct connman_service *service);
 unsigned int __connman_service_get_order(struct connman_service *service);
 
 int __connman_service_set_carrier(struct connman_service *service,
